<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>
	
	<!-- nav_data is defined in main.xslt -->
	<!-- nav_style is defined in main.xslt -->
	<!-- page_id is defined in main.xslt -->
	<xsl:param name="highlight_class" select="'highlight'"/>
	
	<xsl:template match="nav">
		<xsl:variable name="id" select="@id"/>
		<xsl:variable name="cssclass" select="document($nav_style)/styles/style[@section=$id]/@cssclass"/>

				<xsl:apply-templates select="document($nav_data)" mode="nav">
					<xsl:with-param name="highlight" select="$page_id"/>
					<xsl:with-param name="section" select="$id"/>
					<xsl:with-param name="cssclass" select="$cssclass"/>
				</xsl:apply-templates>

	</xsl:template>
	
	<xsl:template match="navigation" mode="nav">
		<xsl:param name="highlight"/>
		<xsl:param name="section"/>
		<xsl:param name="cssclass"/>
		<xsl:element name="div">
			<xsl:attribute name="class"><xsl:value-of select="$cssclass"/></xsl:attribute>
			<ul>
				<xsl:apply-templates mode="nav">
					<xsl:with-param name="highlight" select="$highlight"/>
					<xsl:with-param name="section" select="$section"/>
				</xsl:apply-templates>
			</ul>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="navItem" mode="nav">
		<xsl:param name="highlight"/>
		<xsl:param name="section"/>

		<!-- Make sure we only process the correct section -->
		<xsl:choose>
			<xsl:when test="$section=@section">
				<xsl:element name="li">
					<xsl:element name="a">
						<xsl:if test="($highlight = @id) or ($highlight = descendant::*/@id and (@sectionParent = 'true'))">
							<xsl:attribute name="class"><xsl:value-of select="$highlight_class"/></xsl:attribute>
						</xsl:if>
						<xsl:attribute name="href"><xsl:value-of select="@url"/></xsl:attribute>
						<xsl:value-of select="@title"/>
					</xsl:element>
		 			<xsl:if test="(child::*) and (descendant-or-self::*/@id = $highlight) and (child::*/@section = $section)">
						<ul>
							<xsl:apply-templates mode="nav">
								<xsl:with-param name="highlight" select="$highlight"/>
								<xsl:with-param name="section" select="$section"/>
							</xsl:apply-templates>
						</ul>
		 			</xsl:if>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates mode="nav">
					<xsl:with-param name="highlight" select="$highlight"/>
					<xsl:with-param name="section" select="$section"/>
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>